@@ -2,9 +2,7 @@
 """
 from django.contrib import admin
 
-admin_urls = [
-
-]
+admin_urls = []
 
 urls = admin.site.get_urls()
 admin.site.get_urls = lambda: admin_urls + urls
