@@ -3,8 +3,7 @@
 import logging
 from datetime import timedelta
 
-from celery.schedules import crontab
-from celery.task import periodic_task
+from celery import shared_task
 from django.utils import timezone
 
 from core_explore_example_app.settings import QUERIES_MAX_DAYS_IN_DATABASE
@@ -13,7 +12,7 @@ from core_explore_example_app.system.api import get_saved_queries_created_by_app
 logger = logging.getLogger(__name__)
 
 
-@periodic_task(run_every=crontab(minute=0, hour=0))
+@shared_task
 def delete_temporary_saved_queries():
     """Every day at midnight, delete older temporary saved queries.
 
